==> akonadi-search-21.12.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5AkonadiSearch/KF5AkonadiSearchTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiSearchXapian" for configuration ""
set_property(TARGET KF5::AkonadiSearchXapian APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchXapian PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchXapian.so.5.19.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchXapian.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchXapian )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchXapian "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchXapian.so.5.19.0" )

# Import target "KF5::AkonadiSearchCore" for configuration ""
set_property(TARGET KF5::AkonadiSearchCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchCore PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchCore.so.5.19.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchCore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchCore.so.5.19.0" )

# Import target "KF5::AkonadiSearchPIM" for configuration ""
set_property(TARGET KF5::AkonadiSearchPIM APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchPIM PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchPIM.so.5.19.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchPIM.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchPIM )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchPIM "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchPIM.so.5.19.0" )

# Import target "KF5::AkonadiSearchDebug" for configuration ""
set_property(TARGET KF5::AkonadiSearchDebug APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchDebug PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::I18n;KF5::AkonadiCore;KF5::WidgetsAddons;KF5::ConfigCore;KF5::Completion"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchDebug.so.5.19.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchDebug.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchDebug )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchDebug "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchDebug.so.5.19.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> akonadi-search-22.04.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5AkonadiSearch/KF5AkonadiSearchTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::AkonadiSearchXapian" for configuration ""
set_property(TARGET KF5::AkonadiSearchXapian APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchXapian PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchXapian.so.5.20.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchXapian.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchXapian )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchXapian "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchXapian.so.5.20.0" )

# Import target "KF5::AkonadiSearchCore" for configuration ""
set_property(TARGET KF5::AkonadiSearchCore APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchCore PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchCore.so.5.20.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchCore.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchCore )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchCore "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchCore.so.5.20.0" )

# Import target "KF5::AkonadiSearchPIM" for configuration ""
set_property(TARGET KF5::AkonadiSearchPIM APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchPIM PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::AkonadiCore"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchPIM.so.5.20.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchPIM.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchPIM )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchPIM "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchPIM.so.5.20.0" )

# Import target "KF5::AkonadiSearchDebug" for configuration ""
set_property(TARGET KF5::AkonadiSearchDebug APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5::AkonadiSearchDebug PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Widgets;KF5::I18n;KF5::AkonadiCore;KF5::WidgetsAddons;KF5::ConfigCore;KF5::Completion"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchDebug.so.5.20.0"
  IMPORTED_SONAME_NOCONFIG "libKF5AkonadiSearchDebug.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::AkonadiSearchDebug )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::AkonadiSearchDebug "${_IMPORT_PREFIX}/lib/libKF5AkonadiSearchDebug.so.5.20.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
